# TrollHunter

Added Python Package building

## Workflow

- [Github Flow](https://guides.github.com/introduction/flow/)
- Github Projects

## Cloud

- [Digital Ocean](https://m.do.co/c/f9dca2b1ecc8)

## Twint API


## News Indexer

Crawler and indexer



